@@ -13,10 +13,12 @@ import numpy as np
 from tqdm import tqdm
 
 
-STATISTIC_FUNC = dict(median=np.median,
+STATISTIC_FUNC = dict(count=np.size,
+                      median=np.median,
                       mean=np.mean,
                       min=np.min,
                       max=np.max,
+                      std=np.std,
                       sum=np.sum)
 
 
@@ -55,9 +57,11 @@ def _zonal_stats(raster, layer, band, stats, customized_stat,
         band number
     stats: list[str]
         list of strings of valid available statistics:
+        - 'count' returns number of valid values in zone
         - 'mean' returns average over the values within each zone
         - 'median' returns median
         - 'sum' returns the sum of all values in zone
+        - 'std' returns std of all values in zone
         - 'min' returns minimum value
         - 'max' returns maximum value
     customized_stat: dict
